PrettyTextBase class abstract

Inheritance
Implemented types
Implementers

Constructors

PrettyTextBase({required String text, required SourceLocation start, required SourceLocation end})
PrettyTextBase.zeroWidth(String text, SourceLocation location)

Properties

end → SourceLocation
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length int
The length of this span, in characters.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
finalinherited
sourceUrl Uri?
The URL of the source (typically a file) of this span.
no setterinherited
start → SourceLocation
finalinherited
text String
finalinherited
textContent String
The composed string of text, leading spaces, trailing spaces and line endings.
no setteroverride

Methods

accept(PrettyNodeVisitor visitor) → void
override
appendSpace() → void
Adds a space to the end of this node.
appendSpaces(int amount) → void
Adds the given amount of spaces to the end of this node.
compareTo(SourceSpan other) int
Compares two spans.
inherited
highlight({Object? color}) String
Prints the text associated with this span in a user-friendly way.
inherited
message(String message, {Object? color}) String
Formats message in a human-friendly way associated with this span.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prependSpace() → void
Adds a space to the begining of this node.
prependSpaces(int amount) → void
Adds the given amount of spaces to the begining of this node.
toMap() Map<String, dynamic>
Outputs the attributes as a Map.
override
toString() String
A string representation of this object.
inherited
union(SourceSpan other) → SourceSpan
Creates a new span that's the union of this and other.
inherited
updateText(String text) → void
Changes the text of this node with the given text.
writeln([bool append = true]) → void
Adds a line ending to this node.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited